#topsis-Shantam-102017142
Multiple criteria decision making (MCDM) using TOPSIS

## Installation
```pip install topsis-Shantam-102017142```

##Sample Use case
import topsis-Shantam-102017142 as t
t.topsis("input.csv","1,2,1,2,3","+,+,-,+,-","output.csv")
